# encoding=utf-8
from distutils.core import setup

setup(
    name="sxbwc.math_util",
    version="1.0",
    description="山西博微创数学计算工具包",
    author="rongweifeng",
    author_email="65489942@qq.com",
    py_modules=[
        'math_util.demo1',
        'math_util.demo2',
    ]
)